#ifndef _CTX_HANDLER_H
#define _CTX_HANDLER_H

#include <giet_config.h>

/////////////////////////////////////////////////////////////////////////////////
//	Definition of the scheduler structure
/////////////////////////////////////////////////////////////////////////////////

typedef struct static_scheduler_s
{
    unsigned int	context[15][64];		// at most 15 task contexts
    unsigned int	tasks;					// actual number of tasks
    unsigned int	current;				// current task index
    unsigned int	interrupt_vector[32];	// interrupt vector
} static_scheduler_t;


/////////////////////////////////////////////////////////////////////////////////
//  "idle" task index definition
/////////////////////////////////////////////////////////////////////////////////

#define IDLE_TASK_INDEX		14

/////////////////////////////////////////////////////////////////////////////////
//	Definition of the task context slots indexes
/////////////////////////////////////////////////////////////////////////////////

#define CTX_SP_ID		29
#define CTX_RA_ID		31

#define CTX_EPC_ID		32
#define CTX_CR_ID		33
#define CTX_SR_ID		34
#define CTX_BVAR_ID		35

#define CTX_PTPR_ID		39

#define CTX_TTY_ID		40  // Integer : global TTY terminal index 
#define CTX_DMA_ID	    41  // Integer : global DMA channel index
#define CTX_NIC_ID	    42  // Integer : global NIC channel index
#define CTX_TIMER_ID	43  // Integer : user level timer index / UNUSED
#define CTX_PTAB_ID		44  // Pointer : page table virtual base adress
#define CTX_LTID_ID		45  // Integer : local task index (in scheduler) / UNUSED
#define CTX_VSID_ID		46  // Integer : vspace index
#define CTX_RUN_ID		47  // Boolean : task runable

//////////////////////////////////////////////////////////////////////////////////
// 	Prototype of the context switch function
//////////////////////////////////////////////////////////////////////////////////

extern void _ctx_switch();
extern void _ctx_eret();
extern void _ctx_idle();

extern static_scheduler_t _scheduler[];

#endif
